@@ -18,36 +18,42 @@ class Usersets(ApiResource):
         })
 
     def grant_action(self, user_id, action, resource_id, resource_type):
-        return self.dispatch('/v1/usersets/grantAction', HttpMethods.POST, {
+        return self.dispatch('/v1/grants', HttpMethods.POST, {
             'id': user_id,
-            'action': action,
+            'subject_type': 'USERSET',
+            'relation': action,
+            'relation_type': 'ACTION',
             'resource_type': resource_type,
             'resource_id': resource_id,
             'branch': self.branch,
         })
 
     def revoke_action(self, user_id, action, resource_id, resource_type):
-        return self.dispatch('/v1/usersets/revokeAction', HttpMethods.POST, {
+        return self.dispatch('/v1/grants', HttpMethods.DELETE, {
             'id': user_id,
-            'action': action,
+            'subject_type': 'USERSET',
+            'relation': action,
             'resource_type': resource_type,
             'resource_id': resource_id,
             'branch': self.branch,
         })
 
     def grant_role(self, user_id, role_id, resource_id, resource_type):
-        return self.dispatch('/v1/usersets/grantRole', HttpMethods.POST, {
+        return self.dispatch('/v1/grants', HttpMethods.POST, {
             'id': user_id,
-            'role_id': role_id,
+            'subject_type': 'USERSET',
+            'relation': role_id,
+            'relation_type': 'ROLE',
             'resource_type': resource_type,
             'resource_id': resource_id,
             'branch': self.branch,
         })
 
     def revoke_role(self, user_id, role_id, resource_id, resource_type):
-        return self.dispatch('/v1/usersets/revokeRole', HttpMethods.POST, {
+        return self.dispatch('/v1/grants', HttpMethods.DELETE, {
             'id': user_id,
-            'role_id': role_id,
+            'subject_type': 'USERSET',
+            'relation': role_id,
             'resource_type': resource_type,
             'resource_id': resource_id,
             'branch': self.branch,
